@@ -1,11 +1,12 @@
+from unit.utils.configuration import Configuration
 from unit.api.base_resource import BaseResource
 from unit.models.check_deposit import *
 from unit.models.codecs import DtoDecoder
 
+
 class CheckDepositResource(BaseResource):
-    def __init__(self, api_url, token, retries):
-        super().__init__(api_url, token, retries)
-        self.resource = "check-deposits"
+    def __init__(self, configuration: Configuration):
+        super().__init__("check-deposits", configuration)
 
     def create(self, request: CreateCheckDepositRequest) -> Union[UnitResponse[CheckDepositDTO], UnitError]:
         payload = request.to_json_api()
